import hashlib, requests, bs4, re, os, sys

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }

def stringToSHA512(string):

    result = hashlib.sha512(string.encode()) #Create a SHA512 hash object

    return result.hexdigest() #Return the required hexadecimal hash

def verifySHA512(sha512):
    sha512Regex = re.compile(r'^[0-9a-f]{128}$') #Create a regex object
    mo = sha512Regex.search(sha512) #Create a match object

    if mo == None:
        return False
    else:
        return True

def sha512ToString(sha512):

    sha512 = sha512.lower()

    if not verifySHA512(sha512):
        print(colors['error'] + 'Invalid hash')
        sys.exit()
    else:

        URL='https://md5decrypt.net/en/Sha512/' #Create a url
        myobj = {
            'hash':sha512,
            'captcha13126':'',
            'ahah13126':'8239e6d5b8e2f67f34cfbd3c77b05523',
            'decrypt':'Decrypt'
            }

        res = requests.post(url=URL, data=myobj) #Send a POST request
        res.raise_for_status()

        source = res.content

        soup = bs4.BeautifulSoup(source, 'lxml') #Create a beautiful soup bject

        css_path = 'html body div#corps fieldset#answer b'
        elem = soup.select(css_path) #Find the required element

        try:
            print(colors['msg'] + 'Cracked!\n' + colors['success'] + sha512 + ':' + elem[0].text) #Print the cracked string
        except:
            print(colors['msg'] + 'Hash not found in databases')

def sha512Brute(sha512, wordlist):

    if os.path.exists(wordlist) and os.path.isfile(wordlist): #Check if the wordlist exists
        if not os.path.isabs(wordlist): #Check if it is an absolute path
            wordlist = os.path.abspath(wordlist)
    else:
        print(colors['error'] + 'Invalid path')
        sys.exit()

    if not verifySHA512(sha512): #Verify if hash is correct
        print(colors['error'] + 'Invalid hash')
        sys.exit()

    with open(wordlist, 'r', errors='replace') as w:
        words = w.readlines() #Store all words in a list

    for word in words:
        sha512String = stringToSHA512(word.rstrip())

        if sha512String == sha512: #Check if hash matches
            print(colors['msg'] + 'Cracked!')
            print(colors['success'] + sha512 + ':' + word)
            break
    else:
        print(colors['msg'] + 'Not found')



import hashlib, re, sys, requests, bs4, os

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }
 
def stringToMD4(string):

    result = hashlib.new('md4',string.encode('utf-8')) #Create an MD4 hash object

    return result.hexdigest() #Return the required hexadecimal hash

def verifyMD4(md4):
    md4Regex = re.compile(r'^[0-9a-f]{32}$') #Create a regex object
    mo = md4Regex.search(md4.lower()) #Create a match object

    if mo == None:
        return False
    else:
        return True

def md4ToString(md4):

    if not verifyMD4(md4):
        print(colors['error'] + 'Invalid hash')
        sys.exit()
    else:
        URL = 'https://md5decrypt.net/en/Md4/' #Create a url
        myobj = {
            'hash':md4,
            'captcha65':'',
            'ahah65':'ea1f3b6fdf11511d0a4fa2ae757132db',
            'decrypt':'Decrypt'
            }

        res = requests.post(url=URL, data=myobj) #Send a POST request
        res.raise_for_status()
        
        source = res.content

        soup = bs4.BeautifulSoup(source, 'lxml') #Create a beautiful soup object

        css_path = 'html body div#corps fieldset#answer b'
        elem = soup.select(css_path) #Find the required element

        try:
            print(colors['msg'] + 'Cracked!' + '\n' + colors['success'] + md4 + ':' + elem[0].text) #Print the cracked string
        except:
            print(colors['msg'] + 'Hash not found in databases')

def md4Brute(md4, wordlist):

    md4 = md4.lower()
    
    if os.path.exists(wordlist) and os.path.isfile(wordlist): #Check if the wordlist exists and if it is a file
        if not os.path.isabs(wordlist): #Check if it is an absolute path
            wordlist = os.path.abspath(wordlist)
    else:
        print(colors['error'] + 'Invalid path') #Exit program if invalid path
        sys.exit()

    if not verifyMD4(md4):  #Verify if hash is correct
        print(colors['error'] + 'Invalid hash')
        sys.exit()

    with open(wordlist, 'r', errors='replace') as w:
        words = w.readlines()   #Store all lines in a list

    for word in words:
        md4String = stringToMD4(word.rstrip())

        if md4String == md4:    #Check if hash matches
            print(colors['msg'] + 'Cracked!')
            print(colors['success'] + md4 + ":" + word)
            break
    else:
        print(colors['msg'] + "Not found")



import sys

small = ['!', '"', '#', '$', '%', '&', "'", '(', ')',
         '*', '+', ',', '-', '.', '/', '0', '1', '2',
         '3', '4', '5', '6', '7', '8', '9', ':', ';',
         '<', '=', '>', '?', '@', 'A', 'B', 'C', 'D',
         'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M',
         'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V',
         'W', 'X', 'Y', 'Z', '[', '\\', ']', '^', '_',
         '`', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h',
         'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q',
         'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z',
         '{', '|', '}', '~']

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }

def rot47Encrypt(text):
    res = ''

    for i in range(len(text)):

        if text[i] in small:
            ind = small.index(text[i]) #Find the index of character
            res += small[(ind + 47)%94] #Shift the character

        elif text[i] == ' ':
            res += ' '

        else:
            print(colors['error'] + 'Invalid characters!') #Check for invalid characters
            print(text[i])
            sys.exit()

    print(colors['success'] + res)

def rot47Decrypt(text):
    res = ''

    for i in range(len(text)):

        if text[i] in small:
            ind = small.index(text[i]) #Find the index of character
            res += small[ind - 47] #Shift the character

        elif text[i] == ' ':
            res += ' '

        else:
            print(colors['error'] + 'Invalid characters!') #Check for invalid characters
            sys.exit()

    print(colors['success'] + res)



import sys

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }

def hexadecimalEncode(text):
    res = ' '.join(format(ord(i), '08x').lstrip('0') for i in text)

    print(colors['success'] + res)

def hexadecimalDecode(hexadecimal):

    bytesObj = bytes.fromhex(hexadecimal)

    res = bytesObj.decode('ASCII')

    print(colors['success'] + res)



import os, re, sys, hashlib

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }

def stringToSHA224(string):

    result = hashlib.sha224(string.encode()) #Create a sha224 hash object

    return result.hexdigest() #Return the required hexadecimal hash

def verifySHA224(sha224):
    sha224Regex = re.compile(r'^[0-9a-f]{56}$') #Create a regex object
    mo = sha224Regex.search(sha224.lower()) #Create a match object

    if mo == None:
        return False
    else:
        return True

def sha224ToString(sha224):
    print(colors['msg'] + 'The online "de-hashing" facility for sha224\
 is not available yet, you can still try to bruteforce the hash using 7uring.')
    sys.exit()

def sha224Brute(sha224, wordlist):

    sha224 = sha224.lower()

    if os.path.exists(wordlist) and os.path.isfile(wordlist): #Check if wordlist exists
        if not os.path.isabs(wordlist): #Check if it is an absolute path
            wordlist = os.path.abspath(wordlist)
    else:
        print(colors['error'] + 'Invalid path')
        sys.exit()

    if not verifySHA224(sha224): #Verify if hash is correct
        print(colors['error'] + 'Invalid hash')
        sys.exit()

    with open(wordlist, 'r', errors='replace') as w:
        words = w.readlines() #Store all words in a list

    for word in words:
        sha224String = stringToSHA224(word.rstrip())

        if sha224String == sha224: #Check if hash matches
            print(colors['msg'] + 'Cracked!')
            print(colors['success'] + sha224 + ':' + word)
            break
    else:
        print(colors['msg'] + 'Not found')



import hashlib, requests, bs4, re, os, sys

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }

def stringToSHA1(string):
    
    result = hashlib.sha1(string.encode()) #Create a SHA1 hash object

    return result.hexdigest() #Return the required hexadecimal hash

def verifySHA1(sha1):
    
    sha1Regex = re.compile(r'^[a-f0-9]{40}$') #SHA-1 regex object
    mo = sha1Regex.search(sha1.lower()) #Create a match object

    if mo == None:
        return False
    else:
        return True

def sha1ToString(sha1):
    
    if not verifySHA1(sha1):
        print(colors['error'] + 'Invalid hash')
        sys.exit()
    else:
        url = 'https://sha1.gromweb.com/?hash=' + sha1 #Create url for scraping

        res = requests.get(url) #Query the url
        res.raise_for_status()

        source = res.content

        soup = bs4.BeautifulSoup(source, 'lxml') #Create a beautiful soup object

        css_path = 'html body div#page.p-1.p-3-lg div#container section#section article div#content p em.long-content.string'
        elem = soup.select(css_path)

        try:
            print(colors['msg'] + 'Cracked!\n' + colors['success'] + sha1 + ':' + elem[0].text) #Print the cracked string
        except:
            print(colors['msg'] + 'Hash not found in databases')

def sha1Brute(sha1, wordlist):

    sha1 = sha1.lower()
    
    if os.path.exists(wordlist) and os.path.isfile(wordlist): #Check if the wordlist exists and if it is a file
        if not os.path.isabs(wordlist): #Check if it is an absolute path
            wordlist = os.path.abspath(wordlist)
    else:
        print(colors['error'] + 'Invalid path')
        sys.exit()

    if not verifySHA1(sha1): #Verify if hash is correct
        print(colors['error'] + 'Invalid hash')
        sys.exit()

    with open(wordlist, 'r', errors='replace') as w:
        words = w.readlines() #Store all words in a list

    for word in words:
        sha1String = stringToSHA1(word.rstrip())

        if sha1String == sha1: #Check if hash matches
            print(colors['msg'] + 'Cracked!')
            print(colors['success'] + sha1 + ':' + word)
            break
    else:
        print(colors['msg'] + 'Not found')



#!/usr/bin/python3
colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m '
    }

subcommand = ['hash', 'cipher', 'encoder']

hashes = ['--blake2b', '--md4', '--md5', '--ntlm', '--sha1',
          '--sha224', '--sha256', '--sha384', '--sha512', '--whirlpool']

ciphers = ['--bacon', '--caesar', '--monoalphabetic', '--morse',
           '--multitapsms', '--rot13', '--rot47', '--transposition']

encoders = ['--binary', '--octal', '--hexadecimal', '--base64']

options = ['--enc', '--dec', '--brute', '--rainbow']

menu = colors['msg'] + '''
Usage: 7uring [subcommand] [format] [option] [suboptions] data

[SUBCOMMANDS]
hash    -  To use hash functions and crack hashes.
cipher  -  To use cipher tools.
encoder -  To encode in some popular encoding mechanisms.


[FORMATS]

[Hashes]           [Ciphers]              [Encodings]
--blake2b          --bacon                --binary
--md4              --caesar               --octal
--md5              --monoalphabetic       --hexadecimal
--ntlm             --morse                --base64
--sha1             --multitapsms
--sha224           --rot13
--sha256           --rot47
--sha384           --transposition
--sha512
--whirlpool

[OPTIONS]
--enc     -   To encrypt using that format.
--dec     -   To decrypt that format. (Not for hashes)
--brute   -   To bruteforce the hashes and ciphers. Available for all hashes and
              caesar cipher.
--rainbow -   To crack hashes using rainbow tables.
              (Faster than brute but low chances)

[SUBOPTIONS]

[For --brute]
-w  -  To specify the wordlist path

'''

def printMenu():
    print(menu)



import sys, math

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }

def transpositionEncrypt(text, key):
    textl = list(text)
    
    if ' ' in textl:
        for i in range(textl.count(' ')):
            textl.remove(' ')

    text = ''.join(textl)
    
    cipher = ''
    k = list(key)
    ksort = sorted(k)
    
    perm = []
    for i in k:
        perm.append(ksort.index(i))
        ksort[ksort.index(i)] = '§'
        
    message = []
    for i in range(math.ceil(len(text)/len(key))): #Create matrix
        message.append(list())
        message[i] = list(text[i*len(key):(i*len(key))+len(key)])
        if len(message[i]) < len(key):
            message[i].extend(list(' '*(len(key)-len(message[i]))))

    for i in range(len(key)):
        for j in range(math.ceil(len(text)/len(key))):
            if i == perm[i]:
                cipher += message[j][i]
            else:
                cipher += message[j][perm.index(i)]

    print(colors['success'] + cipher)

def transpositionDecrypt(text, key):
    decipher = ''
    k = list(key)
    ksort = sorted(k)
    
    perm = []
    for i in k:
        perm.append(ksort.index(i))
        ksort[ksort.index(i)] = '§'

    #permNew = list(range(len(key)))
        
    message = []
    for i in range(math.ceil(len(text)/len(key))):
        message.append(list())
        message[i].extend(list(' '*len(key)))

    c = 0
    for i in range(len(key)):
        for j in range(math.ceil(len(text)/len(key))):
            try:
                message[j][i] = text[c]
            except:
                message[j][i] = ' '

            c += 1

    for i in range(math.ceil(len(text)/len(key))):
        for j in range(len(key)):
            if j == perm[j]:
                decipher += message[i][j]
            else:
                decipher += message[i][perm[j]]

    print(colors['success'] + decipher)



import base64, re, sys

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }

def base64Encode(text):
    textBytes = text.encode('ascii')

    base64Bytes = base64.b64encode(textBytes)
    b64 = base64Bytes.decode('ascii')

    print(colors['success'] + b64)

def verifyBase64(b64):
    base64Regex = re.compile(r'^[0-9a-zA-Z+=/]+$') #Create a regex object
    mo = base64Regex.search(b64) #Create a match object

    if mo == None:
        return False
    else:
        return True

def base64Decode(b64):
    
    if not verifyBase64(b64): #Check if bse64 string is valid
        print(colors['error'] + 'Invalid base64 string')
        sys.exit()
        
    base64Bytes = b64.encode('ascii')

    textBytes = base64.b64decode(base64Bytes)
    text = textBytes.decode('ascii')

    print(colors['success'] + text)



#!/usr/bin/python3
from turing.programfiles.menu import *
from turing.programfiles.banner import *
import sys
from turing.hashing.hashmd5 import *
from turing.hashing.hashsha512 import *
from turing.hashing.hashsha1 import *
from turing.hashing.hashsha256 import *
from turing.hashing.hashsha224 import *
from turing.hashing.hashsha384 import *
from turing.hashing.hashmd4 import *
from turing.hashing.hashblake2b import *
from turing.hashing.hashwhirlpool import *
from turing.hashing.hashntlm import *
from turing.cipher.caesar import *
from turing.cipher.morse import *
from turing.cipher.rot13 import *
from turing.cipher.transposition import *
from turing.cipher.multitapSMS import *
from turing.cipher.bacon import *
from turing.cipher.monoalphabetic import *
from turing.cipher.rot47 import *
from turing.encoder.binary import *
from turing.encoder.octal import *
from turing.encoder.hexadecimal import *
from turing.encoder.base64 import *

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'header':'\033[94;1m',
    'msg':'\033[33;1m[o] '
    }

def cliPro(argv):
    printBanner()

    if 'hash' in argv and '--brute' in argv and '-w' not in argv:
        print('\n' + colors['error'] + 'Wordlist (-w) not specified')
        sys.exit()

    if 'hash' in argv and '--brute' in argv and '-w' in argv and len(argv) < 7:
        print('\n' + colors['error'] + 'All arguments not specified! \
7uring --help for help menu.\n')
        sys.exit()

    if '--brute' in argv and '-w' in argv and len(argv) >= 7:
        wordlist = argv[5]
        data = ' '.join(argv[6:])
        
    elif len(argv) >= 5:
        data = ' '.join(argv[4:])

    if len(argv) < 2:
        print('\n' + colors['error'] + 'No arguments specified! \
7uring --help for help menu.\n')
        sys.exit()

    elif '--help' in argv or '-h' in argv:
        printMenu()

    elif len(argv) < 5:
        print('\n' + colors['error'] + 'All arguments not specified! \
7uring --help for help menu.\n')
        sys.exit()

    elif argv[1].lower() not in subcommand:
        print(colors['error'] + 'Unrecognized subcommand.')
        sys.exit()

    elif argv[1].lower() == 'hash':
        if argv[2].lower() not in hashes:
            print(colors['error'] + 'Unrecognized hash type.')
            sys.exit()

        elif argv[3].lower() not in options:
            print(colors['error'] + 'Unrecognized option ' + '\'' + argv[3] + '\'')
            sys.exit()

        elif argv[2].lower() == '--md5':
            if argv[3] == '--enc':
                print(colors['success'] + stringToMD5(data))

            elif argv[3] == '--dec':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for hashes. Use --rainbow or --brute\
 instead.')
                sys.exit()

            elif argv[3] == '--rainbow':
                md5ToString(data)

            else:
                md5Brute(data, wordlist)

        elif argv[2].lower() == '--blake2b':
            if argv[3] == '--enc':
                print(colors['success'] + stringToBlake2b(data))

            elif argv[3] == '--dec':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for hashes. Use --rainbow or --brute\
 instead.')
                sys.exit()

            elif argv[3] == '--rainbow':
                blake2bToString(data)

            else:
                blake2bBrute(data, wordlist)

        elif argv[2].lower() == '--md4':
            if argv[3] == '--enc':
                print(colors['success'] + stringToMD4(data))

            elif argv[3] == '--dec':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for hashes. Use --rainbow or --brute\
 instead.')
                sys.exit()

            elif argv[3] == '--rainbow':
                md4ToString(data)

            else:
                md4Brute(data, wordlist)

        elif argv[2].lower() == '--ntlm':
            if argv[3] == '--enc':
                print(colors['success'] + stringToNTLM(data))

            elif argv[3] == '--dec':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for hashes. Use --rainbow or --brute\
 instead.')
                sys.exit()

            elif argv[3] == '--rainbow':
                ntlmToString(data)

            else:
                ntlmBrute(data, wordlist)

        elif argv[2].lower() == '--sha1':
            if argv[3] == '--enc':
                print(colors['success'] + stringToSHA1(data))

            elif argv[3] == '--dec':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for hashes. Use --rainbow or --brute\
 instead.')
                sys.exit()

            elif argv[3] == '--rainbow':
                sha1ToString(data)

            else:
                sha1Brute(data, wordlist)

        elif argv[2].lower() == '--sha224':
            if argv[3] == '--enc':
                print(colors['success'] + stringToSHA224(data))

            elif argv[3] == '--dec':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for hashes. Use --rainbow or --brute\
 instead.')
                sys.exit()

            elif argv[3] == '--rainbow':
                sha224ToString(data)

            else:
                sha224Brute(data, wordlist)

        elif argv[2].lower() == '--sha256':
            if argv[3] == '--enc':
                print(colors['success'] + stringToSHA256(data))

            elif argv[3] == '--dec':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for hashes. Use --rainbow or --brute\
 instead.')
                sys.exit()

            elif argv[3] == '--rainbow':
                sha256ToString(data)

            else:
                sha256Brute(data, wordlist)

        elif argv[2].lower() == '--sha384':
            if argv[3] == '--enc':
                print(colors['success'] + stringToSHA384(data))

            elif argv[3] == '--dec':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for hashes. Use --rainbow or --brute\
 instead.')
                sys.exit()

            elif argv[3] == '--rainbow':
                sha384ToString(data)

            else:
                sha384Brute(data, wordlist)

        elif argv[2].lower() == '--sha512':
            if argv[3] == '--enc':
                print(colors['success'] + stringToSHA512(data))

            elif argv[3] == '--dec':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for hashes. Use --rainbow or --brute\
 instead.')
                sys.exit()

            elif argv[3] == '--rainbow':
                sha512ToString(data)

            else:
                sha512Brute(data, wordlist)

        elif argv[2].lower() == '--whirlpool':
            if argv[3] == '--enc':
                print(colors['success'] + stringToWhirlpool(data))

            elif argv[3] == '--dec':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for hashes. Use --rainbow or --brute\
 instead.')
                sys.exit()

            elif argv[3] == '--rainbow':
                whirlpoolToString(data)

            else:
                whirlpoolBrute(data, wordlist)

    elif argv[1].lower() == 'cipher':
        if argv[2].lower() not in ciphers:
            print(colors['error'] + 'Unrecognized cipher type.')
            sys.exit()

        elif argv[3].lower() not in options:
            print(colors['error'] + 'Unrecognized option ' + '\'' + argv[3] + '\'')
            sys.exit()

        elif argv[2].lower() == '--bacon':
            if argv[3] == '--enc':
                baconEncrypt(data)

            elif argv[3] == '--dec':
                baconDecrypt(data)

            elif argv[3] == '--rainbow':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers. Use --enc or --dec\
 instead.')
                sys.exit()

            else:
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers(except caesar). Use --enc or --dec\
 instead.')
                sys.exit()

        elif argv[2].lower() == '--caesar':
            
            if argv[3] == '--enc':
                shift = int(input(colors['msg'] + 'Enter shift value: '))
                caesarEncrypt(data, shift)

            elif argv[3] == '--dec':
                shift = int(input(colors['msg'] + 'Enter shift value: '))
                caesarDecrypt(data, shift)

            elif argv[3] == '--rainbow':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers. Use --enc or --dec\
 instead.')
                sys.exit()

            else:
                caesarBrute(data)
                sys.exit()

        elif argv[2].lower() == '--monoalphabetic':
            if argv[3] == '--enc':
                monoalphabeticEncrypt(data)

            elif argv[3] == '--dec':
                monoalphabeticDecrypt(data)

            elif argv[3] == '--rainbow':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers. Use --enc or --dec\
 instead.')
                sys.exit()

            else:
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers(except caesar). Use --enc or --dec\
 instead.')
                sys.exit()

        elif argv[2].lower() == '--morse':
            if argv[3] == '--enc':
                morseEncrypt(data)

            elif argv[3] == '--dec':
                morseDecrypt(data)

            elif argv[3] == '--rainbow':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers. Use --enc or --dec\
 instead.')
                sys.exit()

            else:
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers(except caesar). Use --enc or --dec\
 instead.')
                sys.exit()

        elif argv[2].lower() == '--multitapsms':
            if argv[3] == '--enc':
                multitapEncrypt(data)

            elif argv[3] == '--dec':
                multitapDecrypt(data)

            elif argv[3] == '--rainbow':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers. Use --enc or --dec\
 instead.')
                sys.exit()

            else:
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers(except caesar). Use --enc or --dec\
 instead.')
                sys.exit()

        elif argv[2].lower() == '--rot13':
            if argv[3] == '--enc':
                rot13Encrypt(data)

            elif argv[3] == '--dec':
                rot13Decrypt(data)

            elif argv[3] == '--rainbow':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers. Use --enc or --dec\
 instead.')
                sys.exit()

            else:
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers(except caesar). Use --enc or --dec\
 instead.')
                sys.exit()

        elif argv[2].lower() == '--rot47':
            if argv[3] == '--enc':
                rot47Encrypt(data)

            elif argv[3] == '--dec':
                rot47Decrypt(data)

            elif argv[3] == '--rainbow':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers. Use --enc or --dec\
 instead.')
                sys.exit()

            else:
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers(except caesar). Use --enc or --dec\
 instead.')
                sys.exit()

        elif argv[2].lower() == '--transposition':
            if argv[3] == '--enc':
                key = input(colors['msg'] + 'Enter key value: ')
                transpositionEncrypt(data, key)

            elif argv[3] == '--dec':
                key = input(colors['msg'] + 'Enter key value: ')
                transpositionDecrypt(data, key)

            elif argv[3] == '--rainbow':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers. Use --enc or --dec\
 instead.')
                sys.exit()

            else:
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for ciphers(except caesar). Use --enc or --dec\
 instead.')
                sys.exit()

    elif argv[1].lower() == 'encoder':
        if argv[2].lower() not in encoders:
            print(colors['error'] + 'Unrecognized encoding type.')
            sys.exit()

        elif argv[3].lower() not in options:
            print(colors['error'] + 'Unrecognized option ' + '\'' + argv[3] + '\'')
            sys.exit()

        elif argv[2].lower() == '--binary':
            if argv[3] == '--enc':
                binaryEncode(data)

            elif argv[3] == '--dec':
                binaryDecode(data)

            elif argv[3] == '--rainbow':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for encoders. Use --enc or --dec\
 instead.')
                sys.exit()

            else:
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for encoders. Use --enc or --dec\
 instead.')
                sys.exit()

        elif argv[2].lower() == '--octal':
            if argv[3] == '--enc':
                octalEncode(data)

            elif argv[3] == '--dec':
                octalDecode(data)

            elif argv[3] == '--rainbow':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for encoders. Use --enc or --dec\
 instead.')
                sys.exit()

            else:
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for encoders. Use --enc or --dec\
 instead.')
                sys.exit()

        elif argv[2].lower() == '--hexadecimal':
            if argv[3] == '--enc':
                hexadecimalEncode(data)

            elif argv[3] == '--dec':
                hexadecimalDecode(data)

            elif argv[3] == '--rainbow':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for encoders. Use --enc or --dec\
 instead.')
                sys.exit()

            else:
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for encoders. Use --enc or --dec\
 instead.')
                sys.exit()

        elif argv[2].lower() == '--base64':
            if argv[3] == '--enc':
                base64Encode(data)

            elif argv[3] == '--dec':
                base64Decode(data)

            elif argv[3] == '--rainbow':
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for encoders. Use --enc or --dec\
 instead.')
                sys.exit()

            else:
                print(colors['error'] + '\'' + argv[3] + '\'' +
                      ', this option is not for encoders. Use --enc or --dec\
 instead.')
                sys.exit()



import sys

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }

char = ['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 
        'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z']

code = ['l', 'd', 'm', 'g', 'b', 'v', 's', 'u', 'x', 'i', 't', 'q', 'r',
        'z', 'c', 'y', 'w', 'a', 'j', 'f', 'h', 'e', 'o', 'k', 'n', 'p']

def monoalphabeticEncrypt(text):
    cipher = ''

    for i in text:
        if i in char:
            cipher += code[char.index(i)] #Find and join correct code
        else:
            cipher += i

    print(colors['success'] + cipher)

def monoalphabeticDecrypt(cipher):
    print('\n' + colors['msg'] + 'Monoalphabetic cipher uses mixed sequence of alphabets \
for encryption, so the message encrypted using other tool cannot be decrypted by \
7uring using it\'s default alphabet sequence.\n')
    decipher = ''

    for i in cipher:
        if i in code:
            decipher += char[code.index(i)] #Find and join correct character
        else:
            decipher += i

    print(colors['success'] + decipher)



import sys

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }

def octalToDecimal(octal):
    octal1 = octal
    decimal, base, temp = 0, 1, octal1

    while(temp):
        lastDigit = temp % 10
        temp = int(temp / 10)
        decimal += lastDigit * base
        base *= 8

    return decimal

def octalEncode(text):
    res = ' '.join(format(ord(i), '08o').lstrip('0') for i in text)

    print(colors['success'] + res)

def octalDecode(octal):

    res = ''
    
    if ' ' in octal:
        octList = octal.split()

    for i in octList:
        decimal = octalToDecimal(int(i))

        res += chr(decimal)

    print(colors['success'] + res)



import sys, re

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }

def binaryToDecimal(binary):
    binary1 = binary
    decimal, i, n = 0, 0, 0

    while(binary != 0):
        dec = binary % 10
        decimal = decimal + dec * pow(2, i)
        binary = binary // 10
        i += 1

    return decimal

def binaryEncode(text):
    res = ' '.join(format(ord(i), '08b').lstrip('0') for i in text)

    print(colors['success'] + res)

def verifyBinary(binary):
    binaryRegex = re.compile(r'^(0|1|\s)+$') #Create a regex object
    mo = binaryRegex.search(binary) #Create a match object

    if mo == None:
        return False
    else:
        return True

def binaryDecode(binary):

    res = ''
    
    if ' ' in binary:
        binList = binary.split()

    for i in binList:
        decimal = binaryToDecimal(int(i))

        res += chr(decimal)

    print(colors['success'] + res)



import sys

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }

chars = ['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i',
         'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r',
         's', 't', 'u', 'v', 'w', 'x', 'y', 'z', ' ']

codes = ['2', '22', '222', '3', '33', '333', '4', '44', '444',
         '5', '55', '555', '6', '66', '666', '7', '77', '777',
         '7777', '8', '88', '888', '9', '99', '999', '9999', '0']

def multitapEncrypt(text):
    for i in text:
        if not i.isalpha() and not i.isspace(): #Check if characters are valid
            print(colors['error'] + 'Only english alphabets and\
whitespaces allowed!')
            sys.exit()
            
    cipher = ''
    
    for i in text:
        cipher += codes[chars.index(i.lower())] #Find and join codes
        cipher += ' '

    print(colors['success'] + cipher) #Print the result

def multitapDecrypt(cipher):
    for i in cipher:
        if not i.isdigit() and not i.isspace(): #Check if cipher is valid
            print(colors['error'] + 'Only digits and whitespaces allowed!')
            sys.exit()

    decipher = ''

    for i in cipher.split():
        if not i == ' ':
            try:
                decipher += chars[codes.index(i)] #Find and join characters
            except:
                print(colors['error'] + 'Invalid code')
                sys.exit()

    print(colors['success'] + decipher) #Print the result



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="7uring", 
    version="1.0.0",
    author="Karthik UJ",
    author_email="karthikuj2001@gmail.com",
    description="An advanced cryptography tool.",
    long_description=' An advanced cryptography tool for hashing, encrypting, encoding, steganography and more.',
    long_description_content_type="text/markdown",
    url="https://github.com/karthikuj/7uring",
    project_urls={
        "Bug Tracker": "https://github.com/karthikuj/7uring/issues",
    },
    download_url = 'https://github.com/karthikuj/7uring/archive/refs/tags/v1.0.tar.gz',
    install_requires=[            
          'requests',
          'beautifulsoup4',
          'pyenchant',
      ],
    entry_points = {
        'console_scripts': [
            '7uring = turing.turing:main'
        ]
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    keywords = ['hashing', 'encoding', 'encryption', 'steganography', 'cryptanalysis', 'steganalysis', 'cipher'],
    zip_safe = False,
    packages=setuptools.find_packages(),
    python_requires=">=3.6",
)



import sys

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }

chars = [
    'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i',
    'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r',
    's', 't', 'u', 'v', 'w', 'x', 'y', 'z']

codes = [
    'AAAAA', 'AAAAB', 'AAABA', 'AAABB', 'AABAA', 'AABAB', 'AABBA', 'AABBB', 
    'ABAAA', 'ABAAA', 'ABAAB', 'ABABA', 'ABABB', 'ABBAA', 'ABBAB', 'ABBBA',
    'ABBBB', 'BAAAA', 'BAAAB', 'BAABA', 'BAABB', 'BAABB', 'BABAA', 'BABAB',
    'BABBA', 'BABBB'
    ]

def baconEncrypt(text):
    for i in text:
        if not i.isalpha() and not i.isspace(): #Check if characters are valids
            print(colors['error'] + 'Only english alphabets and \
whitespaces allowed!')
            sys.exit()
            
    cipher = ''
    for i in text:
        if i == ' ':
            cipher += ' '
        else:
            cipher += codes[chars.index(i.lower())] #Find and join the codes

    print(colors['success'] + cipher) #Print the result

def baconDecrypt(cipher):
    '''for i in cipher:
        if (not i.lower() == 'a' or not i.lower() == 'b') and not i.isspace():
            print(colors['error'] + 'Only works with bacon cipher of \'A\' \
and \'B\' as of now')
            sys.exit()'''

    decipher = ''
    i = 0
    while i < len(cipher):
        if cipher[i] == ' ':
            decipher += ' '
            i += 1
        else:
            decipher += chars[codes.index(cipher[i:i+5])]
            i += 5

    print(colors['success'] + decipher)



import sys, enchant

small = ['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm',
         'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z']

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }

def caesarEncrypt(text, shift):
    res = ''

    if shift < 0 or shift > 25:
        print(colors['error'] + 'Shift value should be 0-25') #Shift value check

    for i in range(len(text)):

        if text[i].isupper():
            ind = small.index(text[i].lower()) #Find the index of character
            res += small[(ind + shift)%26].upper() #Shift the character
            
        elif text[i].islower():
            ind = small.index(text[i]) #Find the index of character
            res += small[(ind + shift)%26] #Shift the character

        elif text[i] == ' ':
            res += ' '

        else:
            print(colors['error'] + 'Invalid characters!') #Check for invalid characters
            sys.exit()
            
    print(colors['success'] + res)

def caesarDecrypt(text, shift):
    res = ''

    if shift < 0 or shift > 25:
        print(colors['error'] + 'Shift value should be 0-25') #Shift value check

    for i in range(len(text)):

        if text[i].isupper():
            ind = small.index(text[i].lower()) #Find the index of character
            res += small[ind - shift].upper() #Shift the character

        elif text[i].islower():
            ind = small.index(text[i]) #Find the index of character
            res += small[ind - shift] #Shift the character

        elif text[i] == ' ':
            res += ' '

        else:
            print(colors['error'] + 'Invalid characters!') #Check for invalid characters
            sys.exit()

    print(colors['success'] + res)

def caesarBrute(text):

    possible = set()
    
    for shift in range(26):
        res = ''

        for i in range(len(text)):

            if text[i].isupper():
                ind = small.index(text[i].lower()) #Find the index of character
                res += small[ind - shift].upper() #Shift the character

            elif text[i].islower():
                ind = small.index(text[i]) #Find the index of character
                res += small[ind - shift] #Shift the character

            elif text[i] == ' ':
                res += ' '

            else:
                print(colors['error'] + 'Invalid characters!') #Check for invalid characters
                sys.exit()

        print(colors['success'] + 'shift(' + "{:02d}".format(shift) +
              ')' + ' : ' + res)

        dic = enchant.Dict('en_US') #Create a US english Dictionary
        
        for j in res.split():
            if len(j) > 2 and dic.check(j): #Check for english words
                possible.add('shift(' + "{:02d}".format(shift) +
                             ')' + ' : ' + res)
                
    if len(possible) > 0:
        print(colors['success'][:-4] + '\nMost possible solutions:') #Print most possible solutions
        for k in possible:
            print(colors['success'] + k)



from . import caesar

colors = {
    'error':'\033[31;1m[x] ',
    'success':'\033[36;1m[-] ',
    'msg':'\033[33;1m[o] '
    }

def rot13Encrypt(text):
    caesar.caesarEncrypt(text, 13)

def rot13Decrypt(text):
    caesar.caesarDecrypt(text, 13)
